# Elgato-toggle

## Installation
```
pip install elgato-toggle
```

## Sample usage

Toggle a single light:
```shell
elgato-toggle --light=keylight.local
```

Toggle multiple lights via shell expansion:
```shell
elgato-toggle --light=keylight-{left,right}.local
```
